@@ -53,7 +53,8 @@ bs4Badge <- function(..., position = c("left", "right"), status,
 #' 
 #' Beautiful accordion from AdminLTE3 
 #'
-#' @param ... Slot for bs4AccordionItem.
+#' @param ... Slot for \link{bs4AccordionItem}.
+#' @param id Unique accordion id. 
 #' 
 #' @examples 
 #' if(interactive()){
@@ -69,6 +70,7 @@ bs4Badge <- function(..., position = c("left", "right"), status,
 #'      title = "test",
 #'      body = bs4DashBody(
 #'       bs4Accordion(
+#'        id = "accordion",
 #'        bs4AccordionItem(
 #'         id = "item1",
 #'         title = "Item 1", 
@@ -113,10 +115,21 @@ bs4Badge <- function(..., position = c("left", "right"), status,
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #'
 #' @export
-bs4Accordion <- function(...) {
+bs4Accordion <- function(..., id) {
+  
+  items <- list(...)
+  len <- length(items)
+  
+  # patch that enables a proper accordion behavior
+  # we add the data-parent non standard attribute to each
+  # item. Each accordion must have a unique id.
+  lapply(1:len, FUN = function(i) {
+    items[[i]]$children[[1]]$children[[2]]$attribs[["data-parent"]] <<- paste0("#", id, "accordion") 
+  })
+  
   shiny::tags$div(
-    class = "accordion",
-    ...
+    id = paste0(id, "accordion"),
+    items
   )
 }
 
@@ -143,12 +156,14 @@ bs4AccordionItem <- function(..., id, title = NULL, status = NULL, width = 12) {
   # header
   headerTag <- shiny::tags$div(
     class = "card-header",
+    id = paste0("header_", id),
     shiny::tags$h4(
       class = "card-title",
       shiny::tags$a(
         href = paste0("#", id),
+        `aria-controls` = id,
+        `data-target` = paste0("#", id),
         `data-toggle` = "collapse",
-        `data-parent` = "accordion",
         title
       )
     )
@@ -156,8 +171,9 @@ bs4AccordionItem <- function(..., id, title = NULL, status = NULL, width = 12) {
   
   # body
   bodyTag <- shiny::tags$div(
-    class = "panel-collapse collapse in",
+    `aria-labelledby` = paste0("header_", id),
     id = id,
+    class = "panel-collapse collapse in",
     shiny::tags$div(
       class = "card-body",
       ...
@@ -179,7 +195,7 @@ bs4AccordionItem <- function(..., id, title = NULL, status = NULL, width = 12) {
 #' 
 #' Beautiful carousel from AdminLTE3 
 #'
-#' @param ... Slot for bs4CarouselItem.
+#' @param ... Slot for \link{bs4CarouselItem}.
 #' @param id Unique carousel id.
 #' @param width Carousel width. Between 1 and 12.
 #' 
@@ -294,7 +310,7 @@ bs4Carousel <- function(..., id, width = 12) {
 
 #' Create a Bootstrap 4 carousel item
 #' 
-#' To insert in a bs4Carousel
+#' To insert in a \link{bs4Carousel}
 #'
 #' @param active Whether the item is active or not at start.
 #' @param src Item path or url.
@@ -341,7 +357,7 @@ bs4CarouselItem <- function(active = FALSE, src = NULL) {
 #'      footer = bs4DashFooter(),
 #'      title = "test",
 #'      body = bs4DashBody(
-#'        title = "Carousel",
+#'        title = "Progress bars",
 #'        bs4Card(
 #'         title = "Progress bars",
 #'         footer = tagList(
@@ -632,7 +648,7 @@ bs4Loading <- function() {
 #'
 #' @description Create a timeline block
 #'
-#' @param ... slot for bs4TimelineLabel or bs4TimelineItem.
+#' @param ... slot for \link{bs4TimelineLabel} or \link{bs4TimelineItem}.
 #' @param reversed Whether the timeline is reversed or not.
 #' @param width Timeline width. Between 1 and 12.
 #' 
@@ -715,8 +731,8 @@ bs4Timeline <- function(..., reversed = TRUE, width = 6) {
 #'
 #' @description Create a timeline label
 #'
-#' @param ... any element.
-#' @param status label status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param ... Any element.
+#' @param status Label status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #' 
@@ -740,14 +756,14 @@ bs4TimelineLabel <- function(..., status = NULL) {
 #'
 #' @description Create a timeline item
 #'
-#' @param ... any element such as bs4TimeLineItemMedia ...
+#' @param ... Any element such as \link{bs4TimelineItemMedia} ...
 #' @param elevation Timeline elevation (numeric). NULL by default.
-#' @param icon item icon such as "clock-o", "times", ...
-#' @param status item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
-#' @param time item date or time.
-#' @param title item title.
+#' @param icon Item icon such as "clock-o", "times", ...
+#' @param status Item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param time Item date or time.
+#' @param title Item title.
 #' @param border Whether to display a border between the header and the body. TRUE by default.
-#' @param footer item footer if any.
+#' @param footer Item footer if any.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #' 
@@ -815,9 +831,9 @@ bs4TimelineItem <- function(..., elevation = NULL, icon = NULL,
 #'
 #' @description Create a timeline media item
 #'
-#' @param src media url or path.
-#' @param height media height in pixels.
-#' @param width media width in pixels.
+#' @param src Media url or path.
+#' @param height Media height in pixels.
+#' @param width Media width in pixels.
 #' 
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #' 
@@ -838,8 +854,8 @@ bs4TimelineItemMedia <- function(src = NULL, height = NULL, width = NULL) {
 #'
 #' @description Create a timeline starting point
 #'
-#' @param icon item icon such as "clock-o", "times", ...
-#' @param status item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param icon Item icon such as "clock-o", "times", ...
+#' @param status Item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #' 
@@ -860,8 +876,8 @@ bs4TimelineStart <- function(icon = "clock-o", status = NULL) {
 #'
 #' @description Create a timeline ending point
 #'
-#' @param icon item icon such as "clock-o", "times", ...
-#' @param status item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param icon Item icon such as "clock-o", "times", ...
+#' @param status Item status: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
 #' 
@@ -1028,7 +1044,7 @@ bs4Jumbotron <- function(..., title = NULL, lead = NULL, href = NULL, btn_name =
 #'
 #' @description Create a list group
 #'
-#' @param ... Slot for bs4ListGroupItem.
+#' @param ... Slot for \link{bs4ListGroupItem}.
 #' @param width List group width. 4 by default. Between 1 and 12.
 #'
 #' @author David Granjon, \email{dgranjon@@ymail.com}
@@ -1237,4 +1253,577 @@ ionicon <- function(name) {
   if (is.null(name)) stop("Missing icon name")
   cl <- paste0("icon ion-md-", name)
   shiny::tags$i(class = cl)
+}
+
+
+
+#' @title AdminLTE3 attachment container
+#'
+#' @description Create an attachment container, nice to wrap articles...
+#'
+#' @param ... Any element.
+#' @param src Url or path to the image.
+#' @param title Attachment title.
+#' @param title_url External link.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#'
+#' @examples
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shinyApp(
+#'   ui = bs4DashPage(
+#'     bs4DashNavbar(),
+#'     bs4DashSidebar(),
+#'     bs4DashControlbar(),
+#'     bs4DashBody(
+#'      bs4Card(
+#'       title = "Attachment example",
+#'       attachmentBlock(
+#'        src = "http://kiev.carpediem.cd/data/afisha/o/2d/c7/2dc7670333.jpg",
+#'        title = "Test",
+#'        title_url = "http://google.com",
+#'        "This is the content"
+#'       )
+#'      )
+#'     ),
+#'     title = "AttachmentBlock"
+#'   ),
+#'   server = function(input, output) { }
+#'  )
+#' }
+#'
+#' @export
+attachmentBlock <- function(..., src = NULL, title = NULL, title_url = NULL) {
+  shiny::tags$div(
+    class = "attachment-block clearfix",
+    shiny::img(
+      class = "attachment-img",
+      src = src
+    ),
+    shiny::tags$div(
+      class = "attachment-pushed",
+      shiny::tags$h4(
+        class = "attachment-heading",
+        shiny::tags$a(
+          href = title_url,
+          target = "_blank",
+          title
+        )
+      ),
+      shiny::tags$div(
+        class = "attachment-text",
+        ...
+      )
+    )
+  )
+}
+
+
+
+#' @title AdminLTE3 description block
+#'
+#' @description Create a description block, perfect for writing statistics
+#'
+#' @param number Any number.
+#' @param number_color Number color: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param number_icon Number icon, if any. Should be written like "fa fa-times".
+#' @param header Bold text.
+#' @param text Additional text.
+#' @param right_border TRUE by default. Whether to display a right border to
+#'   separate two blocks. The last block on the right should not have a right border.
+#' @param margin_bottom FALSE by default. Set it to TRUE when the
+#'   descriptionBlock is used in a \link{cardPad} context.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#'
+#' @examples
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shinyApp(
+#'   ui = bs4DashPage(
+#'     bs4DashNavbar(),
+#'     bs4DashSidebar(),
+#'     bs4DashControlbar(),
+#'     bs4DashBody(
+#'      bs4Card(
+#'       solidHeader = FALSE,
+#'       title = "Status summary",
+#'       background = NULL,
+#'       width = 4,
+#'       status = "danger",
+#'       footer = fluidRow(
+#'         column(
+#'           width = 6,
+#'           descriptionBlock(
+#'             number = "17%", 
+#'             number_color = "success", 
+#'             number_icon = "fa fa-caret-up",
+#'             header = "$35,210.43", 
+#'             text = "TOTAL REVENUE", 
+#'             right_border = TRUE,
+#'             margin_bottom = FALSE
+#'           )
+#'         ),
+#'         column(
+#'           width = 6,
+#'           descriptionBlock(
+#'             number = "18%", 
+#'             number_color = "danger", 
+#'             number_icon = "fa fa-caret-down",
+#'             header = "1200", 
+#'             text = "GOAL COMPLETION", 
+#'             right_border = FALSE,
+#'             margin_bottom = FALSE
+#'           )
+#'         )
+#'       )
+#'      )
+#'     ),
+#'     title = "Description Blocks"
+#'   ),
+#'   server = function(input, output) { }
+#'  )
+#' }
+#'
+#' @export
+descriptionBlock <- function(number = NULL, number_color = NULL, number_icon = NULL,
+                             header = NULL, text = NULL, right_border = TRUE,
+                             margin_bottom = FALSE) {
+  
+  cl <- "description-block"
+  if (isTRUE(right_border)) cl <- paste0(cl, " border-right")
+  if (isTRUE(margin_bottom)) cl <- paste0(cl, " mb-4")
+  
+  numcl <- "description-percentage"
+  if (!is.null(number_color)) numcl <- paste0(numcl, " text-", number_color)
+  
+  shiny::tags$div(
+    class = cl,
+    shiny::tags$span(
+      class = numcl, 
+      number,
+      if (!is.null(number_icon)) shiny::tags$i(class = number_icon)
+    ),
+    shiny::tags$h5(class = "description-header", header),
+    shiny::tags$span(class = "description-text", text)
+  )
+}
+
+
+
+#' @title AdminLTE3 vertical block container
+#'
+#' @description Create a vertical container for \link{descriptionBlock} or other elements
+#'
+#' @param ... Any element such as \link{descriptionBlock}.
+#' @param color Background color: see here for a list of valid colors \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param style Custom CSS, if any.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#'
+#' @examples
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shinyApp(
+#'   ui = bs4DashPage(
+#'     bs4DashNavbar(),
+#'     bs4DashSidebar(),
+#'     bs4DashControlbar(),
+#'     bs4DashBody(
+#'      bs4Card(
+#'       title = "Box with right pad",
+#'       status = "warning",
+#'       fluidRow(
+#'         column(width = 6),
+#'         column(
+#'           width = 6,
+#'           cardPad(
+#'             color = "info",
+#'             descriptionBlock(
+#'               header = "8390", 
+#'               text = "VISITS", 
+#'               right_border = FALSE,
+#'               margin_bottom = TRUE
+#'             ),
+#'             descriptionBlock(
+#'               header = "30%", 
+#'               text = "REFERRALS", 
+#'               right_border = FALSE,
+#'               margin_bottom = TRUE
+#'             ),
+#'             descriptionBlock(
+#'               header = "70%", 
+#'               text = "ORGANIC", 
+#'               right_border = FALSE,
+#'               margin_bottom = FALSE
+#'             )
+#'           )
+#'         )
+#'       )
+#'      )
+#'     ),
+#'     title = "cardPad"
+#'   ),
+#'   server = function(input, output) { }
+#'  )
+#' }
+#'
+#' @export
+cardPad <- function(..., color = NULL, style = NULL) {
+  cl <- "card-pane-right pt-2 pb-2 pl-4 pr-4"
+  if (!is.null(color)) cl <- paste0(cl, " bg-", color)
+  
+  shiny::tags$div(
+    class = cl,
+    style = style,
+    ...
+  )
+}
+
+
+
+#' @title AdminLTE3 user message container
+#'
+#' @description Create a user message container
+#'
+#' @param ... Slot for \link{userMessage}.
+#' @param status Messages status. See here for a list of valid colors 
+#' \url{https://adminlte.io/themes/AdminLTE/pages/UI/general.html}.
+#' @param width Container width: between 1 and 12.
+#' 
+#' @note Better to include in a \link{bs4Card}.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#'
+#' @examples
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shinyApp(
+#'   ui = bs4DashPage(
+#'     bs4DashNavbar(),
+#'     bs4DashSidebar(),
+#'     bs4DashControlbar(),
+#'     bs4DashBody(
+#'      userMessages(
+#'       status = "success",
+#'       userMessage(
+#'        author = "Alexander Pierce",
+#'        date = "20 Jan 2:00 pm",
+#'        src = "https://adminlte.io/themes/AdminLTE/dist/img/user1-128x128.jpg",
+#'        side = NULL,
+#'        "Is this template really for free? That's unbelievable!"
+#'       )
+#'      )
+#'     ),
+#'     title = "user Message"
+#'   ),
+#'   server = function(input, output) { }
+#'  )
+#' }
+#'
+#' @export
+userMessages <- function(..., status, width = 4) {
+  cl <- "direct-chat-messages direct-chat"
+  if (!is.null(status)) cl <- paste0(cl, " direct-chat-", status)
+  msgtag <- shiny::tags$div(class = cl, ...)
+  
+  shiny::tags$div(
+    class = if (!is.null(width)) paste0("col-sm-", width),
+    msgtag
+  )
+  
+}
+
+#' @title AdminLTE3 user message 
+#'
+#' @description Create a user message
+#'
+#' @param ... Message text.
+#' @param author Message author.
+#' @param date Message date.
+#' @param src Message author image path or url.
+#' @param side Side where author is displayed: NULL (left, by default) or "right".
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#'
+#' @export
+userMessage <- function(..., author = NULL, date = NULL, 
+                        src = NULL, side = NULL) {
+  
+  messageCl <- "direct-chat-msg"
+  if (!is.null(side)) messageCl <- paste0(messageCl, " right")
+  
+  # message info
+  messageInfo <- shiny::tags$div(
+    class = "direct-chat-info clearfix",
+    shiny::tags$span(
+      class = if (!is.null(side)) {
+        "direct-chat-name float-left"
+      } else {
+        "direct-chat-name float-right"
+      }, 
+      author
+    ),
+    shiny::tags$span(
+      class = if (!is.null(side)) {
+        "direct-chat-timestamp float-right"
+      } else {
+        "direct-chat-timestamp float-left"
+      }, 
+      date
+    )
+  )
+  
+  # message Text
+  messageTxt <- shiny::tags$div(class = "direct-chat-text", ...)
+  
+  # message author image
+  messageImg <- shiny::tags$img(class = "direct-chat-img", src = src)
+  
+  shiny::tags$div(
+    class = messageCl,
+    messageInfo,
+    messageImg, 
+    messageTxt
+  )
+}
+
+
+
+#' @title AdminLTE3 user post
+#'
+#' @description Create a user post
+#'
+#' @param ... Post content, slot for \link{userPostTagItems}, \link{userPostMedia}.
+#' @param id Unique id of the post.
+#' @param src Profile image, if any.
+#' @param author Post author.
+#' @param description Post description.
+#' @param collapsible If TRUE, display a button in the upper right that allows the user to collapse the comment. 
+#' @param collapsed Whether the comment is collapsed when the application starts, FALSE by default.
+#' @param collapse_status Color of the collapse button. NULL by default but also "primary", "info",
+#' "danger", "warning", "success", "secondary" ...
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#' 
+#' @examples
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shinyApp(
+#'   ui = bs4DashPage(
+#'     bs4DashNavbar(),
+#'     bs4DashSidebar(),
+#'     bs4DashControlbar(),
+#'     bs4DashBody(
+#'      bs4Card(
+#'       title = "Box with user comment",
+#'       status = "primary",
+#'       userPost(
+#'        id = 1,
+#'        src = "https://adminlte.io/themes/AdminLTE/dist/img/user1-128x128.jpg",
+#'        author = "Jonathan Burke Jr.",
+#'        description = "Shared publicly - 7:30 PM today",
+#'        "Lorem ipsum represents a long-held tradition for designers, 
+#'        typographers and the like. Some people hate it and argue for 
+#'        its demise, but others ignore the hate as they create awesome 
+#'        tools to help create filler text for everyone from bacon 
+#'        lovers to Charlie Sheen fans.",
+#'        userPostTagItems(
+#'         userPostTagItem(bs4Badge("item 1", status = "warning")),
+#'         userPostTagItem(bs4Badge("item 2", status = "danger"))
+#'        )
+#'       ),
+#'       userPost(
+#'        id = 2,
+#'        src = "https://adminlte.io/themes/AdminLTE/dist/img/user6-128x128.jpg",
+#'        author = "Adam Jones",
+#'        description = "Shared publicly - 5 days ago",
+#'        userPostMedia(src = "https://adminlte.io/themes/AdminLTE/dist/img/photo2.png"),
+#'        userPostTagItems(
+#'         userPostTagItem(bs4Badge("item 1", status = "info")),
+#'         userPostTagItem(bs4Badge("item 2", status = "danger"))
+#'        )
+#'       )
+#'      )
+#'     ),
+#'     title = "userPost"
+#'   ),
+#'   server = function(input, output) { }
+#'  )
+#' }
+#' 
+#' @export
+userPost <- function(..., id = NULL, src = NULL, author = NULL, 
+                     description = NULL, collapsible = TRUE, 
+                     collapsed = FALSE, collapse_status = NULL) {
+  
+  cl <- "collapse"
+  id <- paste0("post-", id)
+  
+  btnCl <- "btn float-right"
+  if(!is.null(collapse_status)) btnCl <- paste0(btnCl, " btn-", collapse_status)
+  
+  shiny::tags$div(
+    class = "post",
+    
+    shiny::tags$div(
+      class = "user-block",
+      shiny::img(class = "img-circle img-bordered-sm", src = src),
+      shiny::tags$span(
+        class = "username", 
+        author,
+        
+        # box tool
+        if (collapsible) {
+          shiny::tags$button(
+            class = btnCl,
+            type = "button",
+            `data-toggle` = "collapse",
+            `data-target` = paste0("#", id),
+            `aria-expanded` = tolower(!collapsed),
+            `aria-controls` = id,
+            shiny::tags$i(class = "fa fa-eye")
+          )
+        }
+        
+      ),
+      shiny::tags$span(class = "description", description)
+    ),
+    shiny::tags$div(
+      class = cl,
+      id = id,
+      shiny::tags$p(...) 
+    )
+  )
+  
+}
+
+
+
+
+#' @title AdminLTE3 user post tool item container
+#'
+#' @description Create a user post tool item container
+#'
+#' @param ... Slot for \link{userPostTagItem}.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#' 
+#' @export
+userPostTagItems<- function(...) {
+  
+  shiny::tags$ul(
+    class = "list-inline d-flex",
+    ...
+  )
+}
+
+
+
+
+#' @title AdminLTE3 user post tool item
+#'
+#' @description Create a user post tool item
+#'
+#' @param ... Tool content such as label, button, ...
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#' 
+#' @export
+userPostTagItem <- function(...) {
+  
+  shiny::tags$li(
+    class = "mx-2",
+    ...
+  )
+}
+
+
+
+#' @title AdminLTE2 user post media
+#'
+#' @description Create a user post media (image)
+#'
+#' @param src Image path or url ...
+#' @param height Media height in pixels.
+#' @param width Media width in pixels.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#' 
+#' @export
+userPostMedia <- function(src = NULL, height = NULL, width = NULL) {
+  shiny::img(
+    style = "margin: auto;",
+    class = "img-fluid", 
+    src = src,
+    height = height,
+    width = width
+  )
+}
+
+
+
+#' @title BS4 sortable section
+#'
+#' @description Create a sortable UI section
+#'
+#' @param ... Slot for UI elements such as \link{bs4Card}.
+#' @param width Section width: between 1 and 12.
+#'
+#' @author David Granjon, \email{dgranjon@@ymail.com}
+#' 
+#' @examples 
+#' if (interactive()) {
+#'  library(shiny)
+#'  library(bs4Dash)
+#'  shiny::shinyApp(
+#'   ui = bs4DashPage(
+#'     navbar = bs4DashNavbar(),
+#'     sidebar = bs4DashSidebar(),
+#'     controlbar = bs4DashControlbar(),
+#'     footer = bs4DashFooter(),
+#'     title = "test",
+#'     body = bs4DashBody(
+#'       bs4TabItems(
+#'         bs4TabItem(
+#'           tabName = "sortabled",
+#'           fluidRow(
+#'             lapply(1:3, FUN = function(i) {
+#'               bs4Sortable(
+#'                 width = 4,
+#'                 p(class = "text-center", paste("Column", i)),
+#'                 lapply(1:2, FUN = function(j) {
+#'                   bs4Card(
+#'                     title = paste0("I am the ", j,"-th card of the ", i, "-th column"), 
+#'                     width = 12,
+#'                     "Click on my header"
+#'                   )
+#'                 })
+#'               )
+#'             })
+#'           )
+#'         )
+#'       )
+#'     )
+#'   ),
+#'   server = function(input, output) {}
+#'  )
+#' }  
+#' 
+#' @export
+bs4Sortable <- function(..., width = NULL) {
+  
+  sectionCl <- "connectedSortable ui-sortable"
+  if (!is.null(width)) sectionCl <- paste0(sectionCl, " col-lg-", width)
+  
+  shiny::tags$section(
+    class = sectionCl,
+    ...
+  ) 
 }
\ No newline at end of file
